@@ -4,7 +4,7 @@ use parent qw(Perinci::CmdLine::I18N Perinci::To::Text::I18N::en);
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.91'; # VERSION
+our $VERSION = '0.92'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -21,7 +21,7 @@ Perinci::CmdLine::I18N::en - English translation for Perinci::CmdLine
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 AUTHOR
 
@@ -50,8 +50,8 @@ __DATA__
 msgid  "There are no subcommands"
 msgstr "There are no subcommands"
 
-msgid  "List of available %1 subcommands"
-msgstr "List of available %1 subcommands"
+msgid  "%1 subcommands"
+msgstr "%1 subcommands"
 
 ### action: version
 
@@ -69,20 +69,20 @@ msgstr "--help (or -h, -?) [--verbose]"
 msgid  "--version (or -v)"
 msgstr "--version (or -v)"
 
-msgid  "--list (or -l)"
-msgstr "--list (or -l)"
+msgid  "--subcommands"
+msgstr "--subcommands"
 
 # usage when there are no subcommands
 msgid  "(options)"
 msgstr "[options]"
 
 # help when there are subcommands and no default subcommand
-msgid  "SUBCOMMAND (options)"
-msgstr "SUBCOMMAND [options]"
+msgid  "<subcommand> (options)"
+msgstr "<subcommand> [options]"
 
 # help when there are subcommands and there is a default subcommand
-msgid  "--cmd=OTHER_SUBCOMMAND (options)"
-msgstr "--cmd=OTHER_SUBCOMMAND [options]"
+msgid  "--cmd=<other-subcommand> (options)"
+msgstr "--cmd=<other-subcommand> [options]"
 
 msgid  "Options"
 msgstr "Options"
@@ -141,7 +141,7 @@ msgstr "Show version"
 msgid  "Display this help message"
 msgstr "Display this help message"
 
-# --list
+# --subcommands
 msgid  "List available subcommands"
 msgstr "List available subcommands"
 
@@ -168,23 +168,26 @@ msgid  "Set log level"
 msgstr "Set log level"
 
 
-msgid  "List of available subcommands"
-msgstr "List of available subcommands"
-
 msgid  "Subcommand"
 msgstr "Subcommand"
 
 msgid  "Subcommands"
 msgstr "Subcommands"
 
-msgid  "For general help, type '%1'"
-msgstr "For general help, type '%1'"
+msgid  "Popular subcommands"
+msgstr "Popular subcommands"
 
-msgid  "For help on a subcommand, type '%1'"
-msgstr "For help on a subcommand, type '%1'"
+msgid  "For general help, use '%1'"
+msgstr "For general help, use '%1'"
 
-msgid  "For more complete help, try '--help --verbose'"
-msgstr "For more complete help, try '--help --verbose'"
+msgid  "For help on a subcommand, use '%1'"
+msgstr "For help on a subcommand, use '%1'"
+
+msgid  "For more complete help, use '--help --verbose'"
+msgstr "For more complete help, use '--help --verbose'"
+
+msgid  "To see all available subcommands, use '--subcommands'"
+msgstr "To see all available subcommands, use '--subcommands'"
 
 # usage/function
 
